@@ -19,7 +19,7 @@ import sys
 from datetime import datetime
 from typing import TYPE_CHECKING, Optional
 
-import requests
+from toil.lib.web import web_session
 
 from docker.errors import ImageNotFound
 from toil.lib.memoize import memoize
@@ -425,7 +425,7 @@ def requestCheckRegularDocker(
     ioURL = "https://{webhost}/v2/{pathName}/manifests/{tag}" "".format(
         webhost=registryName, pathName=imageName, tag=tag
     )
-    response = requests.head(ioURL)
+    response = web_session.head(ioURL)
     if not response.ok:
         raise ApplianceImageNotFound(origAppliance, ioURL, response.status_code)
     else:
@@ -459,10 +459,10 @@ def requestCheckDockerIo(origAppliance: str, imageName: str, tag: str) -> bool:
     )
     requests_url = f"https://registry-1.docker.io/v2/{imageName}/manifests/{tag}"
 
-    token = requests.get(token_url)
+    token = web_session.get(token_url)
     jsonToken = token.json()
     bearer = jsonToken["token"]
-    response = requests.head(
+    response = web_session.head(
         requests_url, headers={"Authorization": f"Bearer {bearer}"}
     )
     if not response.ok:
@@ -480,38 +480,3 @@ def logProcessContext(config: "Config") -> None:
     log.info("Running Toil version %s on host %s.", version, socket.gethostname())
     log.debug("Configuration: %s", config.__dict__)
 
-
-try:
-    cache_path = "~/.cache/aws/cached_temporary_credentials"
-    datetime_format = (
-        "%Y-%m-%dT%H:%M:%SZ"  # incidentally the same as the format used by AWS
-    )
-    log = logging.getLogger(__name__)
-
-    # But in addition to our manual cache, we also are going to turn on boto3's
-    # new built-in caching layer.
-
-    def datetime_to_str(dt):
-        """
-        Convert a naive (implicitly UTC) datetime object into a string, explicitly UTC.
-
-        >>> datetime_to_str(datetime(1970, 1, 1, 0, 0, 0))
-        '1970-01-01T00:00:00Z'
-        """
-        return dt.strftime(datetime_format)
-
-    def str_to_datetime(s):
-        """
-        Convert a string, explicitly UTC into a naive (implicitly UTC) datetime object.
-
-        >>> str_to_datetime( '1970-01-01T00:00:00Z' )
-        datetime.datetime(1970, 1, 1, 0, 0)
-
-        Just to show that the constructor args for seconds and microseconds are optional:
-        >>> datetime(1970, 1, 1, 0, 0, 0)
-        datetime.datetime(1970, 1, 1, 0, 0)
-        """
-        return datetime.strptime(s, datetime_format)
-
-except ImportError:
-    pass
