@@ -4,7 +4,7 @@ from toil.job import Job
 
 class HelloWorld(Job):
     def __init__(self, message):
-        Job.__init__(self,  memory="2G", cores=2, disk="3G")
+        Job.__init__(self)
         self.message = message
 
     def run(self, fileStore):
