@@ -5,10 +5,9 @@ from toil.job import Job
 from toil.lib.docker import apiDockerCall
 from toil.lib.io import mkdtemp
 
-align = Job.wrapJobFn(apiDockerCall,
-                      image='ubuntu',
-                      working_dir=os.getcwd(),
-                      parameters=['ls', '-lha'])
+align = Job.wrapJobFn(
+    apiDockerCall, image="ubuntu", working_dir=os.getcwd(), parameters=["ls", "-lha"]
+)
 
 if __name__ == "__main__":
     jobstore: str = mkdtemp("tutorial_docker")
