@@ -1,12 +1,13 @@
 import os
-import tempfile
 
 from toil.common import Toil
 from toil.job import Job
+from toil.lib.io import mkdtemp
+
 
 class HelloWorld(Job):
     def __init__(self, message):
-        Job.__init__(self,  memory="2G", cores=2, disk="3G")
+        Job.__init__(self)
         self.message = message
 
     def run(self, fileStore):
@@ -14,7 +15,7 @@ class HelloWorld(Job):
 
 
 if __name__ == "__main__":
-    jobstore: str = tempfile.mkdtemp("tutorial_invokeworkflow2")
+    jobstore: str = mkdtemp("tutorial_invokeworkflow2")
     os.rmdir(jobstore)
     options = Job.Runner.getDefaultOptions(jobstore)
     options.logLevel = "INFO"
