@@ -23,13 +23,16 @@ class RealtimeLoggerTest(ToilTest):
     def testRealtimeLogger(self):
         options = Job.Runner.getDefaultOptions(self._getTestJobStorePath())
         options.realTimeLogging = True
-        options.logLevel = 'INFO'
+        options.logLevel = "INFO"
 
         detector = MessageDetector()
 
         # Set up a log message detector to the root logger
         logging.getLogger().addHandler(detector)
 
+        # I believe coloredlogs replaces handlers with its own when doing handler formatting, preserving only filters
+        # https://github.com/xolox/python-coloredlogs/blob/65bdfe976ac0bf81e8c0bd9a98242b9d666b2859/coloredlogs/__init__.py#L453-L459
+        options.colored_logs = False
         Job.Runner.startToil(LogTest(), options)
 
         # We need the message we're supposed to see
@@ -46,19 +49,20 @@ class MessageDetector(logging.StreamHandler):
     def __init__(self):
         self.detected = False  # Have we seen the message we want?
         self.overLogged = False  # Have we seen the message we don't want?
+
         super().__init__()
 
     def emit(self, record):
-        if record.msg == 'This should be logged at info level':
+        if record.msg == "This should be logged at info level":
             self.detected = True
-        if record.msg == 'This should be logged at debug level':
+        if record.msg == "This should be logged at debug level":
             self.overLogged = True
 
 
 class LogTest(Job):
     def __init__(self):
-        Job.__init__(self, memory=100000, cores=1, disk='3G')
+        Job.__init__(self, memory=100000, cores=1, disk="3G")
 
     def run(self, fileStore):
-        RealtimeLogger.info('This should be logged at info level')
-        RealtimeLogger.debug('This should be logged at debug level')
+        RealtimeLogger.info("This should be logged at info level")
+        RealtimeLogger.debug("This should be logged at debug level")
