@@ -26,8 +26,11 @@ logger = logging.getLogger(__name__)
 
 def main() -> None:
     parser = parser_with_common_options(prog="toil kill")
-    parser.add_argument('--force', action='store_true',
-                        help="Send SIGKILL to the leader process if local.")
+    parser.add_argument(
+        "--force",
+        action="store_true",
+        help="Send SIGKILL to the leader process if local.",
+    )
     options = parser.parse_args()
     set_logging_from_options(options)
     config = Config()
@@ -65,7 +68,9 @@ def main() -> None:
             os.kill(pid_to_kill, signal.SIGKILL if options.force else signal.SIGTERM)
             logger.info("Toil process %i successfully terminated.", pid_to_kill)
         except OSError:
-            logger.error("Could not signal process %i. Is it still running?", pid_to_kill)
+            logger.error(
+                "Could not signal process %i. Is it still running?", pid_to_kill
+            )
             sys.exit(1)
     else:
         # Flip the flag inside the job store to signal kill
